pro modisnameparser,name,productname,year,textmonth,day,time,subname,julday

; IDL routine
;
; modisanameparser.pro v 0.5
;
; modisnameparser.pro takes a full modis level 1b granule file name
; parses substrings a returns bit substrings that can be used
; to build a string containing a natural language date.
;
; v 0.5 notes: Hard coded to use leap year dates if the year is 2000
;              This needs to be generalized
;
; Input: 
;    name          string : MODIS granule filename
; 
; Output:
;    productname   string : MODIS product name
;    year          integer: MODIS granule year
;    textmonth     string : MODIS granule month (in English)
;    day           string : MODIS grabule day of the month
;    time          string : 4 digit UTC timestamp (kept as string to preserve leading 0'a
;    subname       string : Fill granule descriptor, minus any file type (ie: .hdf)
;
;
; Required routines:
;    none
;
; Developer
;  v .5 	Mark Gray mag@climate.gsfc.nasa.gov
;               SM&A - SSG
;               MODIS - Atmosphere Group
;

normalyear=[31,28,31,30,31,30,31,31,30,31,30,31]
leapyear  =[31,29,31,30,31,30,31,31,30,31,30,31]
monthname=['January','February','March','April','May',$
           'June','July','August','September', $
           'October','November','Decmeber']
currentyear = normalyear
help, currentyear

if strmid(name,0,1) eq '/' then begin
  allnames=str_sep(name,'/')
  arraysizetemp=size(allnames)
  name=allnames[arraysizetemp[1]-1]
endif

if strmid(name,0,10) eq 'MOD06OD_L2' then begin
  subname=name
  productname=strmid(name,0,10)
  year=fix(strmid(name,12,4))
  day=fix(strmid(name,16,3))
  time=(strmid(name,20,4))
endif else begin
  subname=strmid(name,0,39)
  productname=strmid(name,0,8)
  year=fix(strmid(name,10,4))
  day=fix(strmid(name,14,3))
  time=(strmid(name,18,4))
endelse
;get month
if year eq 2000 then currentyear=leapyear

month=0
while total(currentyear(0:month)) lt day do begin
   month=month+1
endwhile
julday=day
if month gt 0 then begin
   day=fix(day-total(currentyear[0:month-1]))
endif
textmonth=monthname[month]

end

