pro plot_anci, filenames, latlongfile, sds_name, outputname, titlestring, $
               sds_limits, Num_CB_Levels, multidim_choice, latlonglimits, $
               cylindrical=cylindrical, ps=ps, jpeg=jpeg, tiff=tiff,      $
               notation=notation

;*************************************************************************
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody and Mark Gray.
;  eric.moody@gsfc.nasa.gov
;  gray@climate.gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************



if not keyword_set(notation) then titlestring = ''

numberoffiles = size(filenames)
numberoffiles = numberoffiles[1]

if not keyword_set(world) then begin
  if n_elements(latlonglimits) eq 4 then begin
     center=fltarr(2)
     center[0]=(latlonglimits[0]+latlonglimits[2])/2.
     center[1]=(latlonglimits[1]+latlonglimits[3])/2.
  endif else begin
     optimumscale,latlongfile,numberoffiles,scalesetting,center,latlonglimits
  endelse

  print,'Lat/long limits are :'
  print,latlonglimits[0],latlonglimits[2],'   degrees latitude'
  print,latlonglimits[1],latlonglimits[3],'   degrees longitude'

  mapsize = 150
;  worldmap = make_minimap( center[0],center[1],mapsize )
endif

if  keyword_set(world) then begin
    if keyword_set(ps)   then setup_display,filenames,$
                                            titlestring,$
                                            outputname,$
                                            /world,$
                                            /ps
    if keyword_set(jpeg) then setup_display,filenames,$
                                            titlestring,$
                                            outputname,$
                                            /world,$
                                            /jpeg
endif else begin
    if keyword_set(ps) then setup_display,filenames,$
                                          titlestring,$
                                          outputname,$
                                          scalesettings,$
                                          latlonglimits,$
                                          center,$
                                          /ps
    if keyword_set(jpeg) or keyword_set(tiff) and $
       not keyword_set(cylindrical) then setup_display,filenames,$
                                                           titlestring,$
                                                           outputname,$
                                                           scalesettings,$
                                                           latlonglimits,$
                                                           center,$
                                                           /jpeg
    if keyword_set(jpeg) or keyword_set(tiff) and $
       keyword_set(cylindrical) then setup_display,filenames,$
                                                   titlestring,$
                                                   outputname,$
                                                   scalesettings,$
                                                   latlonglimits,$
                                                   center,$
                                                   /jpeg,$
                                                   /cylindrical
endelse

; Having setup the display and some basic notational strings we can get busy with acquiring
; the actual data

imageflag=0
faillist=intarr(numberoffiles)

for fileloop=0,numberoffiles-1 do begin
 print,filenames[fileloop],' is being acquired. Please stand by'
 if keyword_set(world) then  addproduct,filenames[fileloop],$
                                        addimage,$
                                        sds_name,$
                                        xparameter,$
                                        productname,$
                                        sds_limits,$
                                        multidim_choice,$
                                        fail,$
                                        /quick
 if not keyword_set(world) then addproduct,filenames[fileloop],$
                                           latlongfile[fileloop],$
                                           addimage,$
                                           sds_name,$
                                           xparameter,$
                                           productname,$
                                           sds_limits,$
                                           multidim_choice,$
                                           fail

 if fail eq 0 then imageflag=imageflag+1

 if fail  eq 1 then faillist[fileloop]=1

 if  imageflag eq 1 then finalimage=addimage

 if  imageflag gt 1 and fail eq 0 then begin
   unsetpixels = where( finalimage eq 0 ,unsetcount )
   goodaddpixels = where( addimage gt 0,goodaddcount )
   if goodaddcount gt 0 then finalimage(goodaddpixels) = addimage(goodaddpixels)
   addimage = 0
 endif
endfor

totalfail = 0
if total(faillist) lt numberoffiles then begin
  totalfail = 0
endif else begin
  totalfail = 1
endelse


if totalfail eq 0 then begin
  if keyword_set(notation) then begin

;    if not keyword_set(world) then finalimage[0:mapsize-1,0:mapsize-1]=$
;                                      worldmap[0:mapsize-1,0:mapsize-1]

    if keyword_set(ps) then output_productmap,finalimage,$
                                              sds_limits,$
                                              xparameter,$
                                              outputname,$
                                           Num_CB_Levels,$
                                              /psdisplay,$
                                              /notation
    if keyword_set(jpeg) then  output_productmap,finalimage,$
                                                 sds_limits,$
                                                 xparameter,$
                                                 outputname,$
                                              Num_CB_Levels,$
                                                 /jpeg,$
                                                 /notation
    if keyword_set(tiff) then  output_productmap,finalimage,$
                                                 sds_limits,$
                                                 xparameter,$
                                                 outputname,$
                                              Num_CB_Levels,$
                                                 /tiff,$
                                                 /notation
  endif else begin
    if keyword_set(ps) then output_productmap,finalimage,$
                                              sds_limits,$
                                              xparameter,$
                                              outputname,$
                                           Num_CB_Levels,$
                                              /psdisplay
    if keyword_set(jpeg) then  output_productmap,finalimage,$
                                                 sds_limits,$
                                                 xparameter,$
                                                 outputname,$
                                              Num_CB_Levels,$
                                                 /jpeg
    if keyword_set(tiff) then  output_productmap,finalimage,$
                                                 sds_limits,$
                                                 xparameter,$
                                                 outputname,$
                                              Num_CB_Levels,$
                                                 /tiff
  endelse
endif

end
