pro get_annotes, infilename, sds_name, descriptions,valid_values

;+
;.......................................................................
; $Id$
;.......................................................................
; NAME: get_annotes
;	
;
; PURPOSE:
;        Reads the valid range, and the description for each valid value.
;	
;
; CATEGORY:
;        HDF data reader
;
;
; CALLING SEQUENCE:
;	get_annotes, infilename, sds_name, descriptions, valid_range
;
; INPUTS:
;	infilename  :	The file name of a sample input file.
;       sds_name    : 	The sds to read the valids for.
;
; OUTPUTS:
;       descriptions:	The descriptions for each valid value.
;       valid_range :	The range of valid values.
;
; SIDE EFFECTS:
;       None.
;.......................................................................
; REVISION HISTORY:
;       3/7/00	MAG	Updates with proper MODIS names and additional
;                       code to take into account incorrectly set FillValues
;                       in the L-1B data itself. 
;.......................................................................
; PROGRAMMER:  
; 	       Eric G Moody (moody@climate.gsfc.nasa.gov)
;
;              Mark A Gray (gray@climate.gsfc.nasa.gov
;              Jason Li 
;              SM&A Inc | Climate and Radiation Branch
;              NASA Goddard Space Flight Center
;              Greenbelt, Maryland, U.S.A.
;.......................................................................
;-

;Open the file and get the fileID:
fileID = HDF_SD_START(infilename,/READ)


;Select the SDS:
index = HDF_SD_NAMETOINDEX(fileID,sds_name)
sdsid = HDF_SD_SELECT(fileID, index)


;Read in the valid range:
valID = HDF_SD_ATTRFIND(sdsid,'valid_values')
if valID NE -1 THEN BEGIN
   HDF_SD_ATTRINFO, sdsid, valID, DATA = valid_values
endif


;Determine the number of valid values, and thus the number of descripters:
numValids = size(valid_values)
numValids = numValids[1]

print, valid_values

;Get the descriptors:
descriptions = strarr(numValids)
des_num = 0
for icnt = valid_values[0], valid_values[numValids-1] do begin
    print, 'icnt',icnt
    stricnt = string(icnt)
    attrName = 'annot_value_'+strcompress(stricnt,/REMOVE_ALL)
    desID = HDF_SD_ATTRFIND(sdsid,attrName)
    if desID NE -1 THEN BEGIN
       HDF_SD_ATTRINFO, sdsid, desID, DATA = descript
       descriptions[des_num] = descript
    endif
    des_num = des_num + 1
endfor

print, descriptions

;End access to the SDS:
HDF_SD_ENDACCESS, sdsid


;Close the file:
HDF_SD_END, fileId


end
