PRO cloudmaskextracter, inputyear, inputday, inputtime, $
                        MODFileName, ClMaskHDFFileName, ClMaskSDSName

; IDL routine
;
; cloudmaskextracter.pro v 0.5
;
; cloudMaskExtracter.pro will retreive individual cloud mask test results
;   from the full byte cloud mask, from the input file.  The test results
;   are written into an output HDF file, as seperate byte SDSs.  Until the
;   new MOD0 L2 QA plan is implemented, this code only supports the reading
;   of MOD35 files.
;
;
; Input: 
;    inputday		String	   : Julian Day
;    inputyear		String     : Year
;    inputtime		String	   : Time as HHMM (H=hour, M=minute)
;    MODFileName	String	   : The path and name of the MOD granule.
;    ClMaskHDFFileName	String	   : The path and name for the output HDF file.
;    ClMaskSDSName      String	   : The name of the Cloud Mask SDS.
; 
; Output:
;    		none
;
; Required routines:
;    ReadSDS
;    clm_bitextracter
;    outputcloudmaskbits
;
;*************************************************************************
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody and Mark Gray.
;  eric.moody@gsfc.nasa.gov
;  gray@climate.gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;


;*************************************************************************
;Read in the Lat Lons:
;*************************************************************************
MODFileID = HDF_SD_START(MODFileName,/READ)
LatArray = ReadSDS(MODFileID,'Latitude',/scaleNo,/offsetNo)
LonArray = ReadSDS(MODFileID,'Longitude',/scaleNo,/offsetNo)
HDF_SD_END, MODFileID
help, LatArray
help, LonArray


;*************************************************************************
;Extract the individual cloud mask test results:
;*************************************************************************
CloudMaskTests = clm_bitextracter(MODFileName, ClMaskSDSName)


;*************************************************************************
;Output the Cloud Mask Tests and Lat/Lon to the HDF file:
;*************************************************************************
print, ClMaskHDFFileName
outputcloudmaskbits, LatArray, LonArray,                $
                     CloudMaskTests, ClMaskHDFFileName, $
                     inputDay, inputYear, inputTime



END
