pro get_modis_data,filename,latlongfile,sds_name,latitude,longitude,data,$
                   fillvalue,fail,range,multidim_choice

;*************************************************************************
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody and Mark Gray.
;  eric.moody@gsfc.nasa.gov
;  gray@climate.gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


 
fail=0
lat_sdsname='Latitude'
long_sdsname='Longitude'
 
;get data
fileId = HDF_SD_START(latlongfile, /READ)
  latitude = ReadSDS(fileId, lat_sdsname,/offsetno,/scaleno)
  longitude= ReadSDS(fileId, long_sdsname,/offsetno,/scaleno)
HDF_SD_END, fileId

fileId = HDF_SD_START(filename, /READ)
  Read_product_sds,data,range,fillvalue,fileId,sds_name,fail
HDF_SD_END, fileId

;get size of reflectance file
arraysizetemp=size(latitude)
original_nav_x=arraysizetemp(1)
original_nav_y=arraysizetemp(2)

;get dimensions of sds data.  If there is more than one then use
;the multi-dimensional_choice argument to extract it.
temp_sizeinfo=size(data)
if (temp_sizeinfo(0) eq 3) then begin
  if temp_sizeinfo(3) gt temp_sizeinfo(1) then begin
    newdata=fltarr(temp_sizeinfo(2),temp_sizeinfo(3))
    newdata(*,*)=data(multidim_choice,*,*)
    data=newdata
    newdata = 0
  endif
  if temp_sizeinfo(1) gt temp_sizeinfo(3) then begin
    newdata=fltarr(temp_sizeinfo[1],temp_sizeinfo[2])
    newdata[*,*]=data[*,*,multidim_choice]
    data=newdata
    newdata = 0
  endif
endif

;resize and linearly interpolate lat/long arrays to sds size
array_size_temp=size(data)

pixels_in_line=array_size_temp[1]
lines_in_granule=array_size_temp[2]

latitude=congrid(double(latitude),pixels_in_line,lines_in_granule)
longitude=congrid(double(longitude),pixels_in_line,lines_in_granule)

; quick hack to remove lines with missing/bad lat/long datum
; we can skip this if there is no good data (fail=1)
new_array_index=0

if fail eq 0 then begin
  for remove_loop = 0,lines_in_granule-1 do begin
    result1= where( (latitude(*,remove_loop) lt -900.),count1)
    result2= where( (longitude(*,remove_loop) lt -900),count2)
    if  count1 le 0 and count2 le 0 then begin
         latitude[*,new_array_index]=latitude[*,remove_loop]
         longitude[*,new_array_index]=longitude[*,remove_loop]
         data[*,new_array_index,*]=data[*,remove_loop,*]
         new_array_index=new_array_index+1
    endif
  endfor
  if new_array_index eq 0 then begin
     print, 'No nav data in ',filename
  endif else begin
    latitude=latitude[*,0:new_array_index-1]
    longitude=longitude[*,0:new_array_index-1]
    data=data[*,0:new_array_index-1,*]
  endelse
  divisor=fix(lines_in_granule/original_nav_y)


  lines_removed=lines_in_granule-new_array_index-1
  latitude=congrid(latitude,original_nav_x,original_nav_y-fix(lines_removed)/divisor)
  longitude=congrid(longitude,original_nav_x,original_nav_y)
  latitude=congrid(latitude,pixels_in_line,lines_in_granule,/interp)
  longitude=congrid(longitude,pixels_in_line,lines_in_granule,/interp)
endif  

if new_array_index eq 0 then begin
   print, 'No nav data in ',filename
   fail=1
endif else begin
  latitude=latitude[*,0:new_array_index-1]
  longitude=longitude[*,0:new_array_index-1]
  data=data[*,0:new_array_index-1,*]
endelse
end
