pro output_productmap,colorimage,range,xparameter,outputname,Num_CB_Levels, $
            psdisplay=psdisplay,jpeg=jpeg,screen=screen,add=add,tiff=tiff,notation=notation

; IDL routine
;
;  output_productmap.pro v 0.5
;  
;    Outputs an 8-bit image to a jpeg or a ps file 
;
; v 0.5 notes: really needs work. I'd like to avoid using vector fonts in the jpeg output someday.  Image
;              sizing/location in the jpeg output is funny sometimes (xsize/ysize calculated from the 
;              display variables is sometimes wrong. Huh. wierd.) Notation in the ps output isn't always
;              located properly.
;              This code needs more abstraction and better documentation.
;              The option to output to the screen is not used yet.
;              This routine is really not 100% bug proof.  Yes well, even more so than the rest of the code.
;
; Keywords:
;    /psdisplay    output a ps files
;    /jpeg         output a jpeg file
;    /tiff         output a tiff file
;    /add          not currently used (development only)
;    /notation     turns on grids and continents
;    /screen       not implemented
;
; Input:
;
;    colorimage  byte array    3 channel byte image data of the form [n,m,3] where 3rd index is r,g,b
;    range       byte vector   channel max and mins
;    xparameter  real array    image positioning values for locating image in the display device
;    outputname  string        output file name for image
; Output:
;    none
;
; Required routines:  
;    finish_map.pro   draws some map grids and so forth on display device 
;
;*************************************************************************
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody and Mark Gray.
;  eric.moody@gsfc.nasa.gov
;  gray@climate.gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


if  keyword_set(psdisplay) or keyword_set(screen) then begin
   xoffset = xparameter(0)
   yoffset = xparameter(1)
   xsize = xparameter(2)
   ysize = xparameter(3) 
   tv, colorimage, xoffset, $
                yoffset, $
                xsize = xsize,  $
                ysize = ysize

   finish_map,/ps
   ;the last 2 color levels (0,1) are used for notation
   ystart = 1.0 - float(!d.y_size - yoffset)/float(!d.y_size)
   yend   = 1.0 - float(!d.y_size - yoffset-ysize)/float(!d.y_size)
   colorbar,/vertical,/right,position=[0.81, ystart, 0.84, yend],   $
            divisions=Num_CB_Levels,range=range,font=0,             $
            format = '(F6.1)',NCOLORS=254, color = 255
endif
if keyword_set(psdisplay) then begin
  Device,/close
  set_plot,'x'
endif
if keyword_set(add) then begin
   print,'adding data'
   xoffset = xparameter(0)
   yoffset = xparameter(1)
   xsize = xparameter(2)
   ysize = xparameter(3)
   print,'writing output image data'
   tv, bytscl(colorimage,min=range[0],max=range[1]), xoffset, $
                yoffset, $
                xsize = xsize,  $
                ysize = ysize, $
                true=3          
endif

if keyword_set(jpeg) or keyword_set(tiff) then begin
  xoffset =fix(xparameter(0))
  yoffset =fix(xparameter(1))
  xsize = fix(xparameter(2))
  ysize = fix(xparameter(3))


  ;generate map and notation, write to z-buffer and read to image
  ; to  be combined with the colorimage

  ; read data from z-buffer and combine notation to form a single image
  if keyword_set(notation) then finish_map,/jpeg
 
  background=tvrd()
  background_pixels=where(background gt 0,backcount) 

;  colorimage=bytscl(colorimage,min=range[0],max=range[1])

  arraytempsize=size(colorimage)
  newimage=bytarr(!d.x_size,!d.y_size)

; !!this is in the nature of a hack to make sure that the images sizes are consistent
; why they are sometimes not consistent escapes me right now.

  xsize=arraytempsize[1]-1
  ysize=arraytempsize[2]-1 

  newimage[xoffset:xoffset+xsize,yoffset:yoffset+ysize]=colorimage
  if backcount gt 0 then begin
     newimage[background_pixels]=background[background_pixels]
  endif
  if keyword_set(jpeg) then write_jpeg,outputname,newimage,quality=90
  if keyword_set(tiff) then  begin 

;  reorder array for tiff
;   tvlct,r,g,b,/get
   tiff_out=reverse(newimage,2)
   write_tiff,outputname,tiff_out,1,red=r,green=g,blue=b
;   write_tiff,outputname,tiff_out,1
  endif
endif

if keyword_set(screen) then begin

endif
end
