pro GenerateReScaledImage,InputFile,DataType,maxmin,InputXsize,InputYsize,latitude,longitude,channels,rescale,tempoutputimage,xparameter,fileindex,firstfile

; Why V2.0?
; This is a slightly complex routine.  Why all these looping gymnastics?  To save
; memory and make it possible to generate large images.  The v1.0 code plotted the
; individual pixels from the original arrays onto a remapped surface for the entire
; image and then 'dilated' the pixels to fill in the space between the pixels.
; For low resolution level2 products, or small highly magnified regions of level1b
; data the result is not optimal.  
;
;How does this all work?
;
; - the image data from the l1b file is processed in tiles that are 22 lines long and 
;   the full width of the scan (ie 1354 pixels for 1km MODIS, 768 pixels for MAS).
;
; - the tile processing is incremented so that the first and the last lines 
;   of the tiles over lap with the previous and subsequent tiles to produce
;   a seamless image whern all the tiles are combined.
; 
; - for each tile the image and corresponding latitude and longitude arrays 
;   are is rebined N times to produce interpolated larger versions of the tile.
;
; - These tiles are then remapped and the remapped pixels written 
;   to the output image array.
;
; - the output image array is passed out of the routine to be sent to an output
;   image format routine by the main code

;get unique channels
UniqueChannels=channels(sort(channels))

;UniqueChannels=UniqueChannels(uniq(UniqueChannels))

dummy=size(UniqueChannels)

if dummy[0] eq 1 then NumberofChannels=dummy[1]
if dummy[0] eq 0 then NumberofChannels=1

; final image size
ns = !d.x_size
nl = !d.y_size
if ( !d.flags and 1 ) then begin
  ns =1920L 
  nl = long( float( ns ) * float( !d.y_size ) / float( !d.x_size ) )
endif

;  get the tile/s
   imagedata=0
   currenttile=0
;   tilesize=0
   for i=0,NumberofChannels-1 do begin
      case 1 of
        datatype eq 'MODIS' : begin
          GetMODISdata,UniqueChannels[i],$
                   Inputfile,$
                   InputXSize,$
                   InputYSize,$
                   currenttile,$
                   tilesize,rescale,i,saturate,$
                   imagedata_channel
        end
        datatype eq 'MAS' : begin
          GetMASdata,UniqueChannels[i],$
                   Inputfile,$
                   InputXSize,$
                   InputYSize,$
                   currenttile,$
                   tilesize,$
                   imagedata_channel
        end
      endcase
      
      if total(imagedata) eq 0 then begin
         dummy=size(imagedata_channel)
         imagedata=fltarr(dummy[1],dummy[2],NumberofChannels)
         imagedata[*,*,i]=imagedata_channel
         InputXSize=dummy[1]
         InputYSize=dummy[2]
      endif else begin
         imagedata[*,*,i]=imagedata_channel
      endelse
      imagedata_channel=0
   endfor


;get lat long info and resize to the data resolution
   GetLatLongArrays,datatype,InputXsize,InputYsize,InputFile,latitude,longitude

;  remap the tile data to the image
   RemapTileData,Imagedata,$
                 Latitude,$
                 Longitude,$
                 ns,nl,xparameter,$
                 UniqueChannels,$
                 maxmin,$
                 Channels,$
                 outputimage
     
   if currenttile eq 0 and fileindex eq firstfile then begin
      tempoutputimage=outputimage 
   endif else begin
      goodpixels=where(outputimage gt tempoutputimage)
      if total(goodpixels) gt 0 then $
          tempoutputimage[goodpixels]=outputimage[goodpixels]
   endelse
   outputimage=0 

;  set some arrays to 0 to release memory
   outputimage=0
   ScaledImagedata=0
   LatitudeTile=0
   LongitudeTile=0
end
