pro SetupOutputImage,datatype,projection,format,OutputImageXsize,OutputImageYsize,limits,center,scale,imagetitle,outfilename

;notes
;
;  projection :   1  Cylindrical Equidistant
;                 2  Othogonal
;                 3  World, Cylindrical Equidistant
;                 4  World, Robinson
;
;  format     :   1  tiff
;                 2  postscript
;                 3  jpeg
;
;  these are selected in ChooseDisplayOptions

;margins used to set page boundaries for ps output
case 1 of
      format eq 1: begin
                     LocalXMargin=2
                     LocalYMargin=4
      end
      format eq 2: begin
                     LocalXMargin=1
                     LocalYMargin=2
      end
      format eq 3: begin
                     LocalXMargin=2
                     LocalYMargin=4
      end
endcase

;Setup the output device

case 1 of
   format eq 1 or format eq 3: begin
;             the case of rgb or tiff output
;             we need a z-buffer to generate notation

              set_plot,'z'
              !p.font=3
              device,set_resolution=[OutputImageXsize,OutputImageYsize],$
                     set_character_size=[12,18]

;             set z-buffer image to white
              tempimage=bytarr(OutputImageXsize,OutputImageYsize)
              tempimage[0:OutputImageXsize-1,0:OutputImageYsize-1]=255
              tv,tempimage
   end     

   format eq 2: begin
              set_plot,'ps',/interp
              device,bits_per_pixel=8,$
                     /color,$
                     /helv,$
                     font_size=8,$
                     /landscape,$
                     filename=outfilename&!p.font=3
   end
endcase

if datatype eq 'MAS' then begin
  LocalYMargin=3
  LatitudeExtent=abs(limits[0]-limits[2])
  LongitudeExtent=abs(limits[1]-limits[3])
  
  YScreenSize=!d.y_size-(LocalYMargin*!d.Y_ch_size)
  XScreenSize=!d.x_size

  NewXScreenSize=LongitudeExtent/(LatitudeExtent/YScreenSize)
  LocalXMargin=fix(((XScreenSize-NewXScreenSize)/!d.x_ch_size)/2)
endif

if datatype eq 'MODIS' or datatype eq 'LEVEL2' then begin
  LocalXMargin=15
  LocalYMargin=5
endif

;Setup the output map projection
case 1 of

  projection eq 1: begin
; CED 
      map_set,/cylindrical,$
        0.,$
        0.,$
        limit = limits,$
        title = '', $
        xmargin=LocalXMargin,$
        ymargin=LocalYMargin,$
        /noborder,$
        noerase = noerase

  end

  projection eq 2: begin
; Orthogonal 
     if limits[3] lt limits[1] or center[0] lt -70. or center[0] gt 70. then begin
       print,'center plot'
       map_set,/orthographic,$
          center[0],$
          center[1],$
          scale=10e6,$
          xmargin=LocalXMargin,$
          ymargin=LocalYMargin,$
          title='',$
          /noborder,$
          noerase = noerase
     endif else begin
          map_set,/orthographic,$
          center[0],$
          center[1],$
          limit=limits,$
          xmargin=LocalXMargin,$
          ymargin=LocalYMargin,$
          title='',$
          /noborder,$
          noerase = noerase
     endelse
  
  end

  projection eq 3: begin
; CED, World     
      map_set,/cylindrical,0.,0.,$
        xmargin=LocalXMargin,$
        ymargin=LocalYMargin,$
        /noborder,$
        noerase = noerase

  end

  projection eq 4: begin
; Robinson, World    
      map_set,/robinson,$
        0.,$
        0.,$
        /isotropic,$
        /noborder,$
        noerase=noerase
  end

  projection  eq 5 : begin
; Aitoff, World   
      map_set,/aitoff,$
        /isot,$
        /noborder,$
        noerase=noerase
  end
  projection  eq 6 : begin
; polar lambert
  map_set,/lambert,90.,0.,-105,/isotropic,$
        /noborder,$
        noerase = noerase

  end
endcase

clipping=!p.clip
  topspace=!d.y_size-clipping[3]
;  textlinepoint_y=topspace-(fix(!d.y_ch_size/2))+clipping[3]
  textlinepoint_y=clipping[3]+topspace/2
  textlinepoint_x=fix(!d.x_size/2)
  xyouts,textlinepoint_x,textlinepoint_y,imagetitle,/device,alignment=.5,/noclip,charsize=1.1,color=255

end
