pro colorproductmap, Phase_data, lat, lon,colorimage,fillvalue,sds_limits,$
                     log_scale,xparameter,dilateNo=dilateNo,validrange=validrange

;*************************************************************************
; Modification history:
;  11/08/2001
;    Initial Release.
;
; Credits:
;  Written by Eric G. Moody and Mark Gray.
;  eric.moody@gsfc.nasa.gov
;  gray@climate.gsfc.nasa.gov
;  Climate and Radiation Branch
;  NASA Goddard Space Flight Center
;  Greenbelt, Maryland, U.S.A.
;
; License:
; This software is provided "as-is", without any express or
; implied warranty. In no event will the authors be held liable
; for any damages arising from the use of this software.
;
; Permission is granted to anyone to use this software and to alter
; it freely, subject to the following restrictions:
;
; 1. The origin of this software must not be misrepresented; you must
;    not claim you wrote the original software.
;
; 2. Altered source versions must be plainly marked as such, and must
;    not be misrepresented as being the original software.
;
; 3. This notice may not be removed or altered from any source distribution.
;*************************************************************************


;note: Phase_data is (2,x,y), where the indices mean:
;  Phase_data[0,*,*] = Ice
;  Phase_data[1,*,*] = Water, Undetermined, Water+Undetermined

;- set number of samples and lines for warped image
ns = !d.x_size
nl = !d.y_size
if ( !d.flags and 1 ) then begin
  ns = 1280L
  nl = long( float( ns ) * float( !d.y_size ) / float( !d.x_size ) )
endif


;
; Create the conversion table:
;
p = convert_coord( lon, lat, /data, /to_normal )

;
;Byte scale the data in two stages, 
;  where ice is assigned  0  - 126 and
;      water is assigned 127 - 253.
; Values beyond the max and min are set to the upper limit.
;

;Obtain the size of the data arrays:
dimsizes = size(Phase_data)
data_xsize = dimsizes(2)
data_ysize = dimsizes(3)

;Byte scale the ice:
dummy_data  = fltarr(data_xsize,data_ysize)
dummy_data[*,*] = Phase_data[0,*,*]

if (log_scale eq 1) then begin
  ;This should be plotted as log.
  ;store the data in a temp array:
  log_data        = dummy_data

  ;Set the values less than 1 to 1, and convert to log space:
  lt_pixels = where((log_data lt 1.0),ltcnt)
  if ltcnt gt 0 then log_data(lt_pixels) = 1.0
  log_data   = alog10(log_data)
  log_sds_limits = alog10(sds_limits)

  ;Byte scale the data between 0 - 126:
  ice_image = replicate( 0B, ns, nl )
  ice_image( p( 0, * ) * ( ns - 1 ), p( 1, * ) * ( nl - 1 ) ) = $
              bytscl( log_data,                  $
                      min = log_sds_limits(0,0), $
                      max = log_sds_limits(0,1), $
                      top = 126                  ) 

  ;Set the log_data array to zero:
  log_data = 0

endif else begin
  ;This is non-log, so just scale as usual:
  ;Byte scale the data between 0-126-253:
  ;- create resampled byte image
  ice_image = replicate( 0B, ns, nl )
  ice_image( p( 0, * ) * ( ns - 1 ), p( 1, * ) * ( nl - 1 ) ) = $
              bytscl( dummy_data,            $
                      min = sds_limits(0,0), $
                      max = sds_limits(0,1), $
                      top = 126              ) 
endelse

;Set the fill values to 255, or black:
image2 = float(dummy_data)
fill_pixels = where((image2 eq fillvalue),fillcnt)
image2[*,*] = float(sds_limits(0,1))
if fillcnt gt 0 then image2(fill_pixels) = float(sds_limits(0,0))
bottom_vals = replicate( 0B, ns, nl )
bottom_vals( p( 0, * ) * ( ns - 1 ), p( 1, * ) * ( nl - 1 ) ) = $
            bytscl( dummy_data,            $
                    min = sds_limits(0,0), $
                    max = sds_limits(0,1), $
                    top = !d.table_size - 3 )
beyond_scl=where((bottom_vals eq 0B),byndcnt)
if byndcnt gt 0 then ice_image(beyond_scl)=255B

;Set dummy data arrays to 0:
dummy_data = 0
image2 = 0


;Byte scale the water:
dummy_data  = fltarr(data_xsize,data_ysize)
dummy_data[*,*] = Phase_data[1,*,*]

if (log_scale eq 1) then begin
  ;This should be plotted as log.
  ;store the data in a temp array:
  log_data        = dummy_data

  ;Set the values less than 1 to 1, and convert to log space:
  lt_pixels = where((log_data lt 1.0),ltcnt)
  if ltcnt gt 0 then log_data(lt_pixels) = 1.0
  log_data   = alog10(log_data)
  log_sds_limits = alog10(sds_limits)

  ;Byte scale the data between 127-253:
  water_image = replicate( 0B, ns, nl )
  water_image( p( 0, * ) * ( ns - 1 ), p( 1, * ) * ( nl - 1 ) ) = $
              bytscl( log_data,                  $
                      min = log_sds_limits(1,0), $
                      max = log_sds_limits(1,1), $
                      top = 126                  ) + 127B

  ;Set the log_data array to zero:
  log_data = 0

endif else begin
  ;This is non-log, so just scale as usual:
  ;Byte scale the data between 127-253:
  ;- create resampled byte image
  water_image = replicate( 0B, ns, nl )
  water_image( p( 0, * ) * ( ns - 1 ), p( 1, * ) * ( nl - 1 ) ) = $
              bytscl( dummy_data,            $
                      min = sds_limits(1,0), $
                      max = sds_limits(1,1), $
                      top = 126              ) + 127B 

endelse

;Set the fill values to 255, or black:
image2 = float(dummy_data)
fill_pixels = where((image2 eq fillvalue),fillcnt)
image2[*,*] = float(sds_limits(1,1))
if fillcnt gt 0 then image2(fill_pixels) = float(sds_limits(1,0))
bottom_vals = replicate( 0B, ns, nl )
bottom_vals( p( 0, * ) * ( ns - 1 ), p( 1, * ) * ( nl - 1 ) ) = $
            bytscl( dummy_data,            $
                    min = sds_limits(1,0), $
                    max = sds_limits(1,1), $
                    top = !d.table_size - 3 )
beyond_scl=where((bottom_vals eq 0B),byndcnt)
if byndcnt gt 0 then water_image(beyond_scl)=255B

;Set dummy data arrays to 0:
dummy_data = 0
image2 = 0


;Combine the two images into one:
;Start with the ice image:
comb_image = ice_image

;Where the water image is not fill, add to the comb_image:
indices = where((water_image ne 255),ind_cnt)
if (ind_cnt gt 0) then comb_image(indices) = water_image(indices)



;store the combined image in "newimage"
newimage = comb_image
comb_image = 0



;- extract portion of image which fits within map boundaries

x = !x.window * ns
y = !y.window * nl
newimage = temporary( newimage( x(0):x(1), y(0):y(1) ) )

;- compute image offset and size (device coordinates)

p = convert_coord( [ x(0), x(1) ] / float( ns ), [ y(0), y(1) ] / float( nl ), $
  /normal, /to_device )
xoffset = p(0,0)
yoffset = p(1,0)
xsize = p(0,1) - p(0,0)
ysize = p(1,1) - p(1,0)

;- fill holes in resampled image

nxr = 4
nyr = 4
if keyword_set( lowres ) then begin
  nxr = 7
  nyr = 7
  if ( !d.flags and 1 ) then begin
    nxr = 5
    nyr = 5
  endif
endif
fill = dilate( newimage, replicate( 1, nxr, nyr ), /gray )
loc = where( ( fill ge 1b ) and ( newimage eq 0 ), count )
if count ge 1 then newimage( loc ) = fill( loc )
fill = 0

;- fill remaining undefined areas of image with the missing value
missing = 0B
loc = where( newimage eq 0B, count )
if ( count ge 1 ) and ( missing gt 0B) then newimage( loc ) = missing

colorimage=newimage

xparameter=intarr(4)
xparameter(0)= xoffset
xparameter(1)= yoffset
xparameter(2)= xsize
xparameter(3) =ysize

end
